@@ -180,6 +180,7 @@ async def _run(provider,
 
     print_info('Authenticating to cloud provider')
     auth_strategy = get_authentication_strategy(provider)
+
     try:
         credentials = auth_strategy.authenticate(profile=profile,
                                                  aws_access_key_id=aws_access_key_id,
@@ -203,8 +204,9 @@ async def _run(provider,
         if not credentials:
             return 101
     except Exception as e:
-        print_exception('Authentication failure: {}'.format(e))
+        print_exception(f'Authentication failure: {e}')
         return 101
+
     # Create a cloud provider object
     try:
         cloud_provider = get_provider(provider=provider,
@@ -226,21 +228,25 @@ async def _run(provider,
                                       programmatic_execution=programmatic_execution,
                                       credentials=credentials)
     except Exception as e:
-        print_exception('Initialization failure: {}'.format(e))
+        print_exception(f'Initialization failure: {e}')
         return 102
 
     # Create a new report
-    report_name = report_name if report_name else cloud_provider.get_report_name()
-    report = ScoutReport(cloud_provider.provider_code,
-                         report_name,
-                         report_dir,
-                         timestamp,
-                         result_format=result_format)
+    try:
+        report_name = report_name if report_name else cloud_provider.get_report_name()
+        report = ScoutReport(cloud_provider.provider_code,
+                             report_name,
+                             report_dir,
+                             timestamp,
+                             result_format=result_format)
 
-    if database_name:
-        database_file, _ = get_filename('RESULTS', report_name, report_dir, file_extension="db")
-        Server.init(database_file, host_ip, host_port)
-        return
+        if database_name:
+            database_file, _ = get_filename('RESULTS', report_name, report_dir, file_extension="db")
+            Server.init(database_file, host_ip, host_port)
+            return
+    except Exception as e:
+        print_exception('Report initialization failure: {}'.format(e))
+        return 103
 
     # If this command, run and exit
     if list_services:
@@ -259,47 +265,68 @@ async def _run(provider,
         except KeyboardInterrupt:
             print_info('\nCancelled by user')
             return 130
+        except Exception as e:
+            print_exception('Unhandled exception thrown while gathering data: {}'.format(e))
+            return 104
 
         # Update means we reload the whole config and overwrite part of it
         if update:
-            print_info('Updating existing data')
-            current_run_services = copy.deepcopy(cloud_provider.services)
-            last_run_dict = report.encoder.load_from_file('RESULTS')
-            cloud_provider.services = last_run_dict['services']
-            for service in cloud_provider.service_list:
-                cloud_provider.services[service] = current_run_services[service]
+            try:
+                print_info('Updating existing data')
+                current_run_services = copy.deepcopy(cloud_provider.services)
+                last_run_dict = report.encoder.load_from_file('RESULTS')
+                cloud_provider.services = last_run_dict['services']
+                for service in cloud_provider.service_list:
+                    cloud_provider.services[service] = current_run_services[service]
+            except Exception as e:
+                print_exception('Failure while updating report: {}'.format(e))
 
     # Partial run, using pre-pulled data
     else:
-        print_info('Using local data')
-        # Reload to flatten everything into a python dictionary
-        last_run_dict = report.encoder.load_from_file('RESULTS')
-        for key in last_run_dict:
-            setattr(cloud_provider, key, last_run_dict[key])
+        try:
+            print_info('Using local data')
+            # Reload to flatten everything into a python dictionary
+            last_run_dict = report.encoder.load_from_file('RESULTS')
+            for key in last_run_dict:
+                setattr(cloud_provider, key, last_run_dict[key])
+        except Exception as e:
+            print_exception('Failure while updating report: {}'.format(e))
 
     # Pre processing
-    cloud_provider.preprocessing(
-        ip_ranges, ip_ranges_name_key)
+    try:
+        print_info('Running pre-processing engine')
+        cloud_provider.preprocessing(ip_ranges, ip_ranges_name_key)
+    except Exception as e:
+        print_exception('Failure while running pre-processing engine: {}'.format(e))
+        return 105
 
     # Analyze config
-    print_info('Running rule engine')
-    finding_rules = Ruleset(cloud_provider=cloud_provider.provider_code,
-                            environment_name=cloud_provider.environment,
-                            filename=ruleset,
-                            ip_ranges=ip_ranges,
-                            account_id=cloud_provider.account_id)
-    processing_engine = ProcessingEngine(finding_rules)
-    processing_engine.run(cloud_provider)
+    try:
+        print_info('Running rule engine')
+        finding_rules = Ruleset(cloud_provider=cloud_provider.provider_code,
+                                environment_name=cloud_provider.environment,
+                                filename=ruleset,
+                                ip_ranges=ip_ranges,
+                                account_id=cloud_provider.account_id)
+        processing_engine = ProcessingEngine(finding_rules)
+        processing_engine.run(cloud_provider)
+    except Exception as e:
+        print_exception('Failure while running rule engine: {}'.format(e))
+        return 106
 
     # Create display filters
-    print_info('Applying display filters')
-    filter_rules = Ruleset(cloud_provider=cloud_provider.provider_code,
-                           environment_name=cloud_provider.environment,
-                           filename='filters.json',
-                           rule_type='filters',
-                           account_id=cloud_provider.account_id)
-    processing_engine = ProcessingEngine(filter_rules)
-    processing_engine.run(cloud_provider)
+    try:
+        print_info('Applying display filters')
+        filter_rules = Ruleset(cloud_provider=cloud_provider.provider_code,
+                               environment_name=cloud_provider.environment,
+                               filename='filters.json',
+                               rule_type='filters',
+                               account_id=cloud_provider.account_id)
+        processing_engine = ProcessingEngine(filter_rules)
+        processing_engine.run(cloud_provider)
+    except Exception as e:
+        print_exception('Failure while applying display filters: {}'.format(e))
+        return 107
 
     # Handle exceptions
     if exceptions:
@@ -309,23 +336,31 @@ async def _run(provider,
             exceptions.process(cloud_provider)
             exceptions = exceptions.exceptions
         except Exception as e:
-            print_exception('Failed to load exceptions: {}'.format(e))
+            print_exception(f'Failed to load exceptions: {e}')
             exceptions = {}
     else:
         exceptions = {}
 
-    run_parameters = {
-        'services': services,
-        'skipped_services': skipped_services,
-        'regions': regions,
-        'excluded_regions': excluded_regions,
-    }
     # Finalize
-    cloud_provider.postprocessing(report.current_time, finding_rules, run_parameters)
+    try:
+        print_info('Running post-processing engine')
+        run_parameters = {
+            'services': services,
+            'skipped_services': skipped_services,
+            'regions': regions,
+            'excluded_regions': excluded_regions,
+        }
+        cloud_provider.postprocessing(report.current_time, finding_rules, run_parameters)
+    except Exception as e:
+        print_exception('Failure while running post-processing engine: {}'.format(e))
+        return 108
 
     # Save config and create HTML report
-    html_report_path = report.save(
-        cloud_provider, exceptions, force_write, debug)
+    try:
+        html_report_path = report.save(cloud_provider, exceptions, force_write, debug)
+    except Exception as e:
+        print_exception('Failure while generating HTML report: {}'.format(e))
+        return 109
 
     # Open the report by default
     if not no_browser:
