@@ -1,7 +1,7 @@
 import copy
 import os
 
-from ScoutSuite.core.console import print_error, print_exception
+from ScoutSuite.core.console import print_error, print_exception, print_debug
 from ScoutSuite.providers.aws.services import AWSServicesConfig
 from ScoutSuite.providers.aws.resources.vpc.base import put_cidr_name
 from ScoutSuite.providers.aws.utils import ec2_classic, get_aws_account_id
@@ -40,7 +40,7 @@ class AWSProvider(BaseProvider):
 
         self.account_id = get_aws_account_id(self.credentials.session)
 
-        super(AWSProvider, self).__init__(report_dir, timestamp,
+        super().__init__(report_dir, timestamp,
                                           services, skipped_services, result_format)
 
     def get_report_name(self):
@@ -48,9 +48,9 @@ class AWSProvider(BaseProvider):
         Returns the name of the report using the provider's configuration
         """
         if self.profile:
-            return 'aws-{}'.format(self.profile)
+            return f'aws-{self.profile}'
         elif self.account_id:
-            return 'aws-{}'.format(self.account_id)
+            return f'aws-{self.account_id}'
         else:
             return 'aws'
 
@@ -79,6 +79,9 @@ class AWSProvider(BaseProvider):
 
         if 'ec2' in self.service_list and 'iam' in self.service_list:
             self._match_instances_and_roles()
+        
+        if 'awslambda' in self.service_list and 'iam' in self.service_list:
+            self._match_lambdas_and_roles()
 
         if 'elbv2' in self.service_list and 'ec2' in self.service_list:
             self._add_security_group_data_to_elbv2()
@@ -95,7 +98,7 @@ class AWSProvider(BaseProvider):
 
         self._add_cidr_display_name(ip_ranges, ip_ranges_name_key)
 
-        super(AWSProvider, self).preprocessing()
+        super().preprocessing()
 
     def _add_cidr_display_name(self, ip_ranges, ip_ranges_name_key):
         if len(ip_ranges):
@@ -233,6 +236,8 @@ class AWSProvider(BaseProvider):
                                                    [g['GroupId']
                                                     for g in current_config['Groups']],
                                                    [])
+            self._complete_information_on_ec2_attack_surface(current_config, current_path, public_ip)
+
         # IPv6
         if 'Ipv6Addresses' in current_config and len(current_config['Ipv6Addresses']) > 0:
             for ipv6 in current_config['Ipv6Addresses']:
@@ -240,6 +245,18 @@ class AWSProvider(BaseProvider):
                 self._security_group_to_attack_surface(self.services['ec2']['external_attack_surface'],
                                                        ip, current_path,
                                                        [g['GroupId'] for g in current_config['Groups']], [])
+                self._complete_information_on_ec2_attack_surface(current_config, current_path, ip)
+
+    def _complete_information_on_ec2_attack_surface(self, current_config, current_path, public_ip):
+        # Get the EC2 instance info
+        ec2_info = self.services
+        for p in current_path[1:-3]:
+            ec2_info = ec2_info[p]
+        # Fill the rest of the attack surface details on that IP
+        self.services['ec2']['external_attack_surface'][public_ip]['InstanceName'] = ec2_info['name']
+        if 'PublicDnsName' in current_config['Association']:
+            self.services['ec2']['external_attack_surface'][public_ip]['PublicDnsName'] = \
+                current_config['Association']['PublicDnsName']
 
     def _map_all_sgs(self):
         sg_map = dict()
@@ -343,7 +360,7 @@ class AWSProvider(BaseProvider):
                 s3_info, bucket_name, iam_entity, allowed_iam_entity, policy_info)
 
     def _update_iam_permissions(self, s3_info, bucket_name, iam_entity, allowed_iam_entity, policy_info):
-        if self.services.get('s3') and self.services.get('iam'):  # validate both services were included in run
+        if 's3' in self.service_list and 'iam' in self.service_list:  # validate both services were included in run
             if bucket_name != '*' and bucket_name in s3_info['buckets']:
                 bucket = s3_info['buckets'][bucket_name]
                 manage_dictionary(bucket, iam_entity, {})
@@ -378,18 +395,17 @@ class AWSProvider(BaseProvider):
             subnet['network_acl'] = acl_id
 
     def match_instances_and_subnets_callback(self, current_config, path, current_path, instance_id, callback_args):
-        if self.services.get('ec2') and self.services.get('vpc'):  # validate both services were included in run
+        if 'ec2' in self.service_list and 'vpc' in self.service_list:  # validate both services were included in run
             subnet_id = current_config['SubnetId']
             if subnet_id:
                 vpc = self.subnet_map[subnet_id]
-                subnet = self.services['vpc']['regions'][vpc['region']
-                ]['vpcs'][vpc['vpc_id']]['subnets'][subnet_id]
+                subnet = self.services['vpc']['regions'][vpc['region']]['vpcs'][vpc['vpc_id']]['subnets'][subnet_id]
                 manage_dictionary(subnet, 'instances', [])
                 if instance_id not in subnet['instances']:
                     subnet['instances'].append(instance_id)
 
     def _match_instances_and_roles(self):
-        if self.services.get('ec2') and self.services.get('iam'):  # validate both services were included in run
+        if 'ec2' in self.service_list and 'iam' in self.service_list:  # validate both services were included in run
             ec2_config = self.services['ec2']
             iam_config = self.services['iam']
             role_instances = {}
@@ -412,6 +428,25 @@ class AWSProvider(BaseProvider):
                         iam_config['roles'][role_id]['instances_count'] += len(
                             role_instances[instance_profile_id])
 
+    def _match_lambdas_and_roles(self):
+        if self.services.get('awslambda') and self.services.get('iam'):
+            awslambda_config = self.services['awslambda']
+            iam_config = self.services['iam']
+            awslambda_funtions = {}
+            for r in awslambda_config['regions']:
+                for lambda_function in awslambda_config['regions'][r]['functions']:
+                    awslambda_function = awslambda_config['regions'][r]['functions'][lambda_function]
+                    awslambda_function['region'] = r
+                    if awslambda_function['role_arn'] in awslambda_funtions:
+                        awslambda_funtions[awslambda_function['role_arn']][awslambda_function['name']] = awslambda_function
+                    else:
+                        awslambda_funtions[awslambda_function['role_arn']] = {awslambda_function['name']: awslambda_function}
+            for role_id in iam_config['roles']:
+                iam_config['roles'][role_id]['awslambdas_count'] = 0
+                if iam_config['roles'][role_id]['arn'] in awslambda_funtions:
+                    iam_config['roles'][role_id]['awslambdas'] = awslambda_funtions[iam_config['roles'][role_id]['arn']]
+                    iam_config['roles'][role_id]['awslambdas_count'] = len(awslambda_funtions[iam_config['roles'][role_id]['arn']])
+
     def process_vpc_peering_connections_callback(self, current_config, path, current_path, pc_id, callback_args):
 
         # Create a list of peering connection IDs in each VPC
@@ -524,19 +559,19 @@ class AWSProvider(BaseProvider):
                             sg['used_by'][service]['resource_type'][resource_type], resource_status, [])
                         if resource_id not in sg['used_by'][service]['resource_type'][resource_type][resource_status]:
                             sg['used_by'][service]['resource_type'][resource_type][resource_status].append(
-                                resource_id)
+                                {'id': resource_id, 'name': resource['name']})
                     else:
                         sg['used_by'][service]['resource_type'][resource_type].append(
-                            resource_id)
+                            {'id': resource_id, 'name': resource['name']})
             except Exception as e:
                 if resource_type == 'elbs' and current_path[5] == ec2_classic:
                     pass
                 elif not self.services['ec2']:  # service not included in run
                     pass
                 elif not str(e):
-                    print_exception('Failed to parse {}'.format(resource_type))
+                    print_exception(f'Failed to parse {resource_type}')
                 else:
-                    print_exception('Failed to parse {}: {}'.format(resource_type, e))
+                    print_exception(f'Failed to parse {resource_type}: {e}')
 
     def _set_emr_vpc_ids(self):
         clear_list = []
@@ -587,39 +622,36 @@ class AWSProvider(BaseProvider):
             callback_args['clear_list'].append(region)
 
     def sort_vpc_flow_logs_callback(self, current_config, path, current_path, flow_log_id, callback_args):
-        # FIXME it's not clear if the below is still necessary/useful
-        return
-
-        # attached_resource = current_config['ResourceId']
-        # if attached_resource.startswith('vpc-'):
-        #     vpc_path = combine_paths(
-        #         current_path[0:4], ['vpcs', attached_resource])
-        #     try:
-        #         attached_vpc = get_object_at(self, vpc_path)
-        #     except Exception:
-        #         print_debug(
-        #             'It appears that the flow log %s is attached to a resource that was previously deleted (%s).' % (
-        #                 flow_log_id, attached_resource))
-        #         return
-        #     manage_dictionary(attached_vpc, 'flow_logs', [])
-        #     if flow_log_id not in attached_vpc['flow_logs']:
-        #         attached_vpc['flow_logs'].append(flow_log_id)
-        #     for subnet_id in attached_vpc['subnets']:
-        #         manage_dictionary(
-        #             attached_vpc['subnets'][subnet_id], 'flow_logs', [])
-        #         if flow_log_id not in attached_vpc['subnets'][subnet_id]['flow_logs']:
-        #             attached_vpc['subnets'][subnet_id]['flow_logs'].append(
-        #                 flow_log_id)
-        # elif attached_resource.startswith('subnet-'):
-        #     subnet_path = combine_paths(current_path[0:4],
-        #                                 ['vpcs', self.subnet_map[attached_resource]['vpc_id'], 'subnets',
-        #                                  attached_resource])
-        #     subnet = get_object_at(self, subnet_path)
-        #     manage_dictionary(subnet, 'flow_logs', [])
-        #     if flow_log_id not in subnet['flow_logs']:
-        #         subnet['flow_logs'].append(flow_log_id)
-        # else:
-        #     print_exception('Resource %s attached to flow logs is not handled' % attached_resource)
+        attached_resource = current_config['resource_id']
+        if attached_resource.startswith('vpc-'):
+            vpc_path = combine_paths(
+                current_path[0:4], ['vpcs', attached_resource])
+            try:
+                attached_vpc = get_object_at(self, vpc_path)
+            except Exception:
+                print_debug(
+                    'It appears that the flow log %s is attached to a resource that was previously deleted (%s).' % (
+                        flow_log_id, attached_resource))
+                return
+            manage_dictionary(attached_vpc, 'flow_logs', [])
+            if flow_log_id not in attached_vpc['flow_logs']:
+                attached_vpc['flow_logs'].append(flow_log_id)
+            for subnet_id in attached_vpc['subnets']:
+                manage_dictionary(
+                    attached_vpc['subnets'][subnet_id], 'flow_logs', [])
+                if flow_log_id not in attached_vpc['subnets'][subnet_id]['flow_logs']:
+                    attached_vpc['subnets'][subnet_id]['flow_logs'].append(
+                        flow_log_id)
+        elif attached_resource.startswith('subnet-'):
+            subnet_path = combine_paths(current_path[0:4],
+                                        ['vpcs', self.subnet_map[attached_resource]['vpc_id'], 'subnets',
+                                         attached_resource])
+            subnet = get_object_at(self, subnet_path)
+            manage_dictionary(subnet, 'flow_logs', [])
+            if flow_log_id not in subnet['flow_logs']:
+                subnet['flow_logs'].append(flow_log_id)
+        else:
+            print_exception('Resource %s attached to flow logs is not handled' % attached_resource)
 
     def get_db_attack_surface(self, current_config, path, current_path, db_id, callback_args):
         service = current_path[1]
@@ -687,6 +719,7 @@ class AWSProvider(BaseProvider):
                                           security_groups, listeners=None):
         listeners = [] if listeners is None else listeners
         manage_dictionary(attack_surface_config, public_ip, {'protocols': {}})
+        instance_path = current_path[:-3]
         if 'ec2' in self.service_list:  # validate that the service was included in run
             for sg_id in security_groups:
                 sg_path = copy.deepcopy(current_path[0:6])
