@@ -6,7 +6,7 @@ from ScoutSuite.providers.utils import get_non_provider_id
 
 class Certificates(AWSResources):
     def __init__(self, facade: AWSFacade, region: str):
-        super(Certificates, self).__init__(facade)
+        super().__init__(facade)
         self.region = region
 
     async def fetch_all(self):
