@@ -10,7 +10,7 @@ class Keys(AWSCompositeResources):
     ]
 
     def __init__(self, facade: AWSFacade, region: str):
-        super(Keys, self).__init__(facade)
+        super().__init__(facade)
         self.region = region
 
     async def fetch_all(self):
