@@ -4,7 +4,7 @@ from ScoutSuite.providers.aws.facade.base import AWSFacade
 
 class HostedZones(AWSResources):
     def __init__(self, facade: AWSFacade, region: str):
-        super(HostedZones, self).__init__(facade)
+        super().__init__(facade)
         self.region = region
 
     async def fetch_all(self):
