@@ -6,7 +6,7 @@ from ScoutSuite.providers.aws.resources.base import AWSResources
 
 class Queues(AWSResources):
     def __init__(self, facade: AWSFacade, region: str):
-        super(Queues, self).__init__(facade)
+        super().__init__(facade)
         self.region = region
 
     async def fetch_all(self):
