@@ -2,6 +2,7 @@ from azure.mgmt.security import SecurityCenter
 
 from ScoutSuite.core.console import print_exception, print_debug
 from ScoutSuite.providers.utils import run_concurrently
+from ScoutSuite.utils import get_user_agent
 
 
 class SecurityCenterFacade:
@@ -10,8 +11,10 @@ class SecurityCenterFacade:
         self.credentials = credentials
 
     def get_client(self, subscription_id: str):
-        return SecurityCenter(self.credentials.get_credentials('arm'),
+        client = SecurityCenter(self.credentials.get_credentials('arm'),
                               subscription_id, '')
+        client._client.config.add_user_agent(get_user_agent())
+        return client
 
     async def get_pricings(self, subscription_id: str):
         try:
@@ -24,7 +27,7 @@ class SecurityCenterFacade:
             else:
                 return []
         except Exception as e:
-            print_exception('Failed to retrieve pricings: {}'.format(e))
+            print_exception(f'Failed to retrieve pricings: {e}')
             return []
 
     async def get_security_contacts(self, subscription_id: str):
@@ -34,7 +37,7 @@ class SecurityCenterFacade:
                 lambda: list(client.security_contacts.list())
             )
         except Exception as e:
-            print_exception('Failed to retrieve security contacts: {}'.format(e))
+            print_exception(f'Failed to retrieve security contacts: {e}')
             return []
 
     async def get_auto_provisioning_settings(self, subscription_id: str):
@@ -44,16 +47,16 @@ class SecurityCenterFacade:
                 lambda: list(client.auto_provisioning_settings.list())
             )
         except Exception as e:
-            print_exception('Failed to retrieve auto provisioning settings: {}'.format(e))
+            print_exception(f'Failed to retrieve auto provisioning settings: {e}')
             return []
 
     async def get_information_protection_policies(self, subscription_id: str):
         try:
             client = self.get_client(subscription_id)
-            scope = '/subscriptions/{}'.format(self._subscription_id)
+            scope = f'/subscriptions/{self._subscription_id}'
             return await run_concurrently(lambda: list(client.information_protection_policies.list(scope=scope)))
         except Exception as e:
-            print_exception('Failed to retrieve information protection policies: {}'.format(e))
+            print_exception(f'Failed to retrieve information protection policies: {e}')
             return []
 
     async def get_settings(self, subscription_id: str):
@@ -63,7 +66,7 @@ class SecurityCenterFacade:
                 lambda: list(client.settings.list())
             )
         except Exception as e:
-            print_exception('Failed to retrieve settings: {}'.format(e))
+            print_exception(f'Failed to retrieve settings: {e}')
             return []
 
     async def get_alerts(self, subscription_id: str):
@@ -73,18 +76,18 @@ class SecurityCenterFacade:
                 lambda: list(client.alerts.list())
             )
         except Exception as e:
-            print_exception('Failed to retrieve alerts: {}'.format(e))
+            print_exception(f'Failed to retrieve alerts: {e}')
             return []
 
     async def get_compliance_results(self, subscription_id: str):
         try:
             client = self.get_client(subscription_id)
-            scope = '/subscriptions/{}'.format(subscription_id)
+            scope = f'/subscriptions/{subscription_id}'
             return await run_concurrently(
                 lambda: list(client.compliance_results.list(scope=scope))
             )
         except Exception as e:
-            print_exception('Failed to retrieve compliance results: {}'.format(e))
+            print_exception(f'Failed to retrieve compliance results: {e}')
             return []
 
     async def get_regulatory_compliance_results(self, subscription_id: str):
@@ -97,24 +100,24 @@ class SecurityCenterFacade:
                 )
             except Exception as e:
                 if 'as it has no standard pricing bundle' in str(e):
-                    print_debug('Failed to retrieve regulatory compliance standards: {}'.format(e))
+                    print_debug(f'Failed to retrieve regulatory compliance standards: {e}')
                 else:
-                    print_exception('Failed to retrieve regulatory compliance standards: {}'.format(e))
+                    print_exception(f'Failed to retrieve regulatory compliance standards: {e}')
                 return {}
             else:
                 for standard in compliance_standards:
                     try:
                         compliance_controls = await run_concurrently(
-                            lambda: list(client.regulatory_compliance_controls.list(
+                            lambda standard=standard: list(client.regulatory_compliance_controls.list(
                                 regulatory_compliance_standard_name=standard.name))
                         )
                         for control in compliance_controls:
                             control.standard_name = standard.name
                             results.append(control)
                     except Exception as e:
-                        print_exception('Failed to retrieve compliance controls: {}'.format(e))
+                        print_exception(f'Failed to retrieve compliance controls: {e}')
             finally:
                 return results
         except Exception as e:
-            print_exception('Failed to retrieve regulatory compliance results: {}'.format(e))
+            print_exception(f'Failed to retrieve regulatory compliance results: {e}')
             return []
