@@ -2,6 +2,7 @@ from azure.mgmt.compute import ComputeManagementClient
 
 from ScoutSuite.core.console import print_exception
 from ScoutSuite.providers.utils import run_concurrently
+from ScoutSuite.utils import get_user_agent
 
 
 class VirtualMachineFacade:
@@ -10,8 +11,10 @@ class VirtualMachineFacade:
         self.credentials = credentials
 
     def get_client(self, subscription_id: str):
-        return ComputeManagementClient(self.credentials.get_credentials('arm'),
+        client = ComputeManagementClient(self.credentials.get_credentials('arm'),
                                        subscription_id=subscription_id)
+        client._client.config.add_user_agent(get_user_agent())
+        return client
 
     async def get_instances(self, subscription_id: str):
         try:
@@ -20,7 +23,7 @@ class VirtualMachineFacade:
                 lambda: list(client.virtual_machines.list_all())
             )
         except Exception as e:
-            print_exception('Failed to retrieve virtual machines: {}'.format(e))
+            print_exception(f'Failed to retrieve virtual machines: {e}')
             return []
 
     async def get_instance_extensions(self, subscription_id: str,
@@ -34,7 +37,7 @@ class VirtualMachineFacade:
             )
             return list(extensions.value)
         except Exception as e:
-            print_exception('Failed to retrieve virtual machine extensions: {}'.format(e))
+            print_exception(f'Failed to retrieve virtual machine extensions: {e}')
             return []
 
     async def get_disks(self, subscription_id: str):
@@ -44,7 +47,7 @@ class VirtualMachineFacade:
                 lambda: list(client.disks.list())
             )
         except Exception as e:
-            print_exception('Failed to retrieve disks: {}'.format(e))
+            print_exception(f'Failed to retrieve disks: {e}')
             return []
 
     async def get_snapshots(self, subscription_id: str):
@@ -54,7 +57,7 @@ class VirtualMachineFacade:
                 lambda: list(client.snapshots.list())
             )
         except Exception as e:
-            print_exception('Failed to retrieve snapshots: {}'.format(e))
+            print_exception(f'Failed to retrieve snapshots: {e}')
             return []
 
     async def get_images(self, subscription_id: str):
@@ -64,5 +67,5 @@ class VirtualMachineFacade:
                 lambda: list(client.images.list())
             )
         except Exception as e:
-            print_exception('Failed to retrieve images: {}'.format(e))
+            print_exception(f'Failed to retrieve images: {e}')
             return []
