@@ -1,6 +1,3 @@
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import copy
 import json
 
@@ -10,7 +7,7 @@ from ScoutSuite.output.html import ScoutReport
 from ScoutSuite.providers.base.configs.browser import get_object_at
 
 
-class BaseProvider(object):
+class BaseProvider:
     """
     Base class for the different providers.
 
@@ -44,6 +41,10 @@ class BaseProvider(object):
             self.services = self.services_config(self.credentials)
         supported_services = vars(self.services).keys()
 
+        # Ensures "credentials" is not included
+        supported_services = list(supported_services)
+        supported_services.remove('credentials')
+
         self.service_list = self._build_services_list(supported_services, services, skipped_services)
 
     def get_report_name(self):
@@ -95,7 +96,7 @@ class BaseProvider(object):
         :return: None
         """
         # Load metadata
-        with open(self.metadata_path, 'rt') as f:
+        with open(self.metadata_path) as f:
             self.metadata = json.load(f)
 
     @staticmethod
@@ -105,7 +106,7 @@ class BaseProvider(object):
         error = False
         for service in services + skipped_services:
             if service not in supported_services:
-                print_error('Service \"{}\" does not exist, skipping'.format(service))
+                print_error(f'Service \"{service}\" does not exist, skipping')
                 error = True
         if error:
             print_info('Available services are: {}'.format(str(list(supported_services)).strip('[]')))
@@ -332,10 +333,10 @@ class BaseProvider(object):
                                                callback_args)
 
         except Exception as e:
-            print_exception(e, {'current path': '{}'.format(current_path),
+            print_exception(e, {'current path': f'{current_path}',
                                 'key': '{}'.format(key if 'key' in locals() else 'not defined'),
                                 'value': '{}'.format(value if 'value' in locals() else 'not defined'),
-                                'path': '{}'.format(path),
+                                'path': f'{path}',
                                 }
                             )
 
@@ -378,11 +379,11 @@ class BaseProvider(object):
                             except Exception as e:
                                 print_exception(e, {'callback': callback_name,
                                                     'callback arguments': callback_args,
-                                                    'current path': '{}'.format(current_path),
+                                                    'current path': f'{current_path}',
                                                     'key': '{}'.format(key if 'key' in locals() else 'not defined'),
                                                     'value': '{}'.format(
                                                         value if 'value' in locals() else 'not defined'),
-                                                    'path': '{}'.format(path),
+                                                    'path': f'{path}',
                                                     }
                                                 )
                     else:
@@ -396,9 +397,9 @@ class BaseProvider(object):
                             tmp.append(i)
                             self._new_go_to_and_do(current_config[key][i], copy.deepcopy(path), tmp, callbacks)
         except Exception as e:
-            print_exception(e, {'current path': '{}'.format(current_path),
+            print_exception(e, {'current path': f'{current_path}',
                                 'key': '{}'.format(key if 'key' in locals() else 'not defined'),
                                 'value': '{}'.format(value if 'value' in locals() else 'not defined'),
-                                'path': '{}'.format(path),
+                                'path': f'{path}',
                                 }
                             )
